#
# spec file for package gmmlib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global somajor 12
%global libname libigdgmm%{somajor}
Name:           gmmlib
Version:        22.3.18
Release:        1.2
Summary:        Intel Graphics Memory Management Library Package
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/intel/gmmlib
Source0:        %{url}/archive/intel-gmmlib-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  pkgconfig
ExclusiveArch:  %{ix86} x86_64 %{x86_64}

%description
The Intel Graphics Memory Management Library provides device specific
and buffer management for the Intel Graphics Compute Runtime for
OpenCL and the Intel Media Driver for VAAPI.

%package -n %{libname}
Summary:        Intel Graphics Memory Management Library development package
Group:          Development/Libraries/C and C++

%description -n %{libname}
The Intel Graphics Memory Management Library provides device specific
and buffer management for the Intel Graphics Compute Runtime for
OpenCL and the Intel Media Driver for VAAPI.

This package contains shared library.

%package    devel
Summary:        Intel Graphics Memory Management Library development package
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Provides:       libigdgmm-devel = %{version}
Obsoletes:      libigdgmm-devel < %{version}

%description   devel
The Intel Graphics Memory Management Library provides device specific
and buffer management for the Intel Graphics Compute Runtime for
OpenCL and the Intel Media Driver for VAAPI.

This package provides development files.

%prep
%autosetup -n %{name}-intel-%{name}-%{version}

%build
chmod a-x LICENSE.md
%cmake -DCMAKE_BUILD_TYPE=Release
%cmake_build

%install
%cmake_install

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE.md
%{_libdir}/libigdgmm.so.%{somajor}*

%files devel
%{_includedir}/igdgmm
%{_libdir}/libigdgmm.so
%{_libdir}/pkgconfig/igdgmm.pc

%changelog
* Tue Mar 26 2024 ming li <mli@suse.com>
- Update to version 22.3.18:
  * Introduce ARL-H support (#172)
  * Added new ADL-N Device IDs (#189)
  * Add new Xe_HP Device IDs (#190)
  * Handle out of memory case (#193)
  * Correct DG2 Depth/Stencil MSAA 16x 8x Texture Allocation (#192)
  * Failing the resource allocation if the U plane offset exceeds
    the HW limitations (#191)
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- update to 22.3.17:
  * Fix possible integer overflow
  * Assert and return on divide by zero (#187)
  * Update DG2 device ID macro (#183)
* Mon Dec 18 2023 Dirk Müller <dmueller@suse.com>
- update to 22.3.16:
  * Fix to align HAlign to 128bytes for Linear Packed YUV format
  * Add PVC device ID
  * Guard FormatTable to be within bound
* Mon Dec  4 2023 Stefan Dirsch <sndirsch@suse.com>
- This includes latest version of one of the components needed for
  Video (processing) hardware support on Intel GPUs (bsc#1217770)
* Fri Nov 17 2023 Dirk Müller <dmueller@suse.com>
- update to 22.3.14:
  * Add more DG2 Device IDs
* Tue Nov 14 2023 Dirk Müller <dmueller@suse.com>
- update to 22.3.13:
  * Fix Multiadapter ULT issue reproducibilty
  * Add new PVC Device ID
* Wed Sep 13 2023 Dirk Müller <dmueller@suse.com>
- update to 22.3.11:
  * Add PVC Device ID
  * Add more MTL Device IDs
  * Replace WaDefaultTile4 with a feature flag
  * Multi-threaded fixes for GMM Context info
  * Use GmmResGetAuxSurfaceOffset64
  * Fix UnifiedAuxSurvface checks to allow HiZ w/o CCS
  * add ARL-S support
  * Add device IDs for RPL
* Sat Apr 15 2023 Dirk Müller <dmueller@suse.com>
- update to 22.3.5:
  * Change Scratch L1 Caching to WB
  * Update Cachepolicy for MTL
  * Add forceful fallback to support Tile4 using an Ftr flag
  * Enable L3 for VP_INPUT_PICTURE_RENDER usage
* Mon Feb 27 2023 Dirk Müller <dmueller@suse.com>
- update to 22.3.4:
  * remove unused tilewidth, mip4height and mip5height variables
* Fri Jan  6 2023 Dirk Müller <dmueller@suse.com>
- update to 22.3.3:
  * Initialize Filedescriptor
  * Disable MultiAdapter ULT testcases
* Thu Dec 15 2022 Dirk Müller <dmueller@suse.com>
- update to 22.3.2:
  * Fix tiling selection
  * Align SURFTYPE_3D surfaces
  * Correct max surface size
- enable building for x86_64 micro-level architectures
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 22.3.1:
  * Fix memory leak Destroy allocated resources for ULT
* Mon Nov  7 2022 Stefan Dirsch <sndirsch@suse.com>
- needed for jira#PED-1174 (Video decoding/encoding support
  (VA-API, ...) for Intel GPUs is outside of Mesa)
* Sun Oct 30 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 22.3.0:
  * Support for default build types
  * Add ATS-M Device Ids
  * Adding more dg2 device Ids
  * Fixing XE_HPC macro usage for Cache Policy settings
  * Fix QPtich calculations for CCS
  * PVC PAT table implementations
  * Initialize NumPATRegisters
  * Add PVC Device IDs
  * Fix GetPrivatePATEntry API
  * Introducing MTL Support
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- No code changes
- Update to version 22.1.4 was part of Intel oneVPL GPU Runtime
  2022Q2 Release 22.4.4
* Wed Jul  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 22.1.4:
  * No upstream changelog available
* Thu May 26 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 22.1.2:
  * No upstream changelog available
* Wed Jan 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 22.0.1:
  * No upstream changelog available.
- Bump somajor define to 12 and in baselibs.conf following upstream
  so bump.
- Replace gcc-c++ with generic c++_compiler BuildRequires.
* Mon Nov 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 21.3.3:
  * No upstream changelog available.
* Thu Oct 28 2021 Jan Engelhardt <jengelh@inai.de>
- Allow building on rpmbuild --target=i686.
- Drop R/TM, too hard to get right.
* Thu Oct 28 2021 Stefan Dirsch <sndirsch@suse.com>
- mention baselibs.conf as source in specfile
* Mon Oct 25 2021 Duarte Pousa <pousaduarte@gmail.com>
- Fix 32bit build (dependency for Steam-in-home streaming)
* Mon Oct  4 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed JIRA number in previous changelog
* Mon Sep 27 2021 Stefan Dirsch <sndirsch@suse.com>
- covers jira#SLE/SLE-19361
* Wed Sep 15 2021 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to 21.2.2
  * No upstream changelog available.
* Sat Oct 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.3.2
  * baseAlignment can be greater than 64KB and needs to be aligned to 64KB
  * DG1 HiZ H/V Align modification
  * Set MOCS0 with WB cache value
  * DG1 Placed resource alignment issues Dx12/Vulkan
  * Remove '-Werror=implicit-function-declaration'
  * SyncInfoLin: Initialize members
  * Do not use memset for clearing an object of non-trivial type
  * Added the ADL-S device ID's and phyAddr support
* Mon Aug 31 2020 Stefan Dirsch <sndirsch@suse.com>
- update to 20.2.5
  * No upstream changelog available (needed for jira#SLE/SLE-12712)
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.2.3:
  * No upstream changelog available.
* Fri Apr 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 20.1.1:
  * No upstream changelog available.
* Mon Mar 23 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 19.4.1:
  * No upstream changelog available
* Thu Nov  7 2019 Stefan Dirsch <sndirsch@suse.com>
- This release fullfills requirements for jsc#SLE-8726
* Wed Nov  6 2019 Stefan Dirsch <sndirsch@suse.com>
- Updated to version 19.3.3
  * Intel Graphics Memory Management Library 2019 Q3 Release 3
- Bump soname to 11
* Mon Sep  2 2019 Stefan Dirsch <sndirsch@suse.com>
- Updated to version 19.2.4
  * adds support for Icelake, EHL, Cometlake, Lakefield
  * bug fixes
* Sat Jul  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 19.2.3:
  * Memory leak fix.
  * Crash fix.
  * More device support.
- Bump soname to 9 following upstream changes.
* Mon Apr  1 2019 tiwai@suse.de
- Updated to version 18.4.1:
  * Cleanup, more device support
- Changed the subpackage name to follow libigdgmm.so.5
* Wed Nov  7 2018 tiwai@suse.de
- Initial version: 18.3.0
